diff --git a/makefiles/tools/jlink.inc.mk b/makefiles/tools/jlink.inc.mk
index a53eb7cb978584361dda185bdabce761d44b62de..af9741807cdd2382cdf120e2e8b0a09860a47a11 100644
--- a/makefiles/tools/jlink.inc.mk
+++ b/makefiles/tools/jlink.inc.mk
@@ -5,7 +5,7 @@ export RESET = $(RIOTTOOLS)/jlink/jlink.sh
 
 HEXFILE = $(BINFILE)
 
-export FFLAGS ?= flash
-export DEBUGGER_FLAGS ?= debug
+export FFLAGS ?= flash $(HEXFILE)
+export DEBUGGER_FLAGS ?= debug $(ELFFILE)
 export DEBUGSERVER_FLAGS ?= debug-server
 export RESET_FLAGS ?= reset
diff --git a/dist/tools/jlink/jlink.sh b/dist/tools/jlink/jlink.sh
index 382c8986844b33d8f19e3867189cea51781e9f94..2e24ae6602bebef081fa1c7c2a7761344ab6a341 100755
--- a/dist/tools/jlink/jlink.sh
+++ b/dist/tools/jlink/jlink.sh
@@ -18,23 +18,25 @@
 #
 # The script supports the following actions:
 #
-# flash:        flash a given hex file to the target.
-#               hexfile is expected in ihex format and is pointed to
-#               by BINFILE environment variable
+# flash:        flash <binfile>
+#
+#               flash given binary format file to the target.
 #
 #               options:
 #               BINFILE: path to the binary file that is flashed
 #
-# debug:        starts JLink as GDB server in the background and
+#               starts JLink as GDB server in the background and
 #               connects to the server with the GDB client specified by
 #               the board (DBG environment variable)
 #
 #               options:
+#               <elffile>:      path to the ELF file to debug
 #               GDB_PORT:       port opened for GDB connections
 #               TELNET_PORT:    port opened for telnet connections
 #               DBG:            debugger client command, default: 'gdb -q'
 #               TUI:            if TUI!=null, the -tui option will be used
-#               ELFFILE:        path to the ELF file to debug
 #
 # debug-server: starts JLink as GDB server, but does not connect to
 #               to it with any frontend. This might be useful when using
@@ -88,10 +90,10 @@ test_config() {
     fi
 }
 
-test_hexfile() {
-    if [ ! -f "${HEXFILE}" ]; then
-        echo "Error: Unable to locate HEXFILE"
-        echo "       (${HEXFILE})"
+test_binfile() {
+    if [ ! -f "${BINFILE}" ]; then
+        echo "Error: Unable to locate BINFILE"
+        echo "       (${BINFILE})"
         exit 1
     fi
 }
@@ -145,16 +147,17 @@ test_term() {
 # now comes the actual actions
 #
 do_flash() {
+    BINFILE=$1
     test_config
     test_serial
-    test_hexfile
+    test_binfile
     # clear any existing contents in burn file
     /bin/echo -n "" > ${BINDIR}/burn.seg
     # create temporary burn file
     if [ ! -z "${JLINK_PRE_FLASH}" ]; then
         printf "${JLINK_PRE_FLASH}\n" >> ${BINDIR}/burn.seg
     fi
-    echo "loadbin ${HEXFILE} ${FLASH_ADDR}" >> ${BINDIR}/burn.seg
+    echo "loadbin ${BINFILE} ${FLASH_ADDR}" >> ${BINDIR}/burn.seg
     if [ ! -z "${JLINK_POST_FLASH}" ]; then
         printf "${JLINK_POST_FLASH}\n" >> ${BINDIR}/burn.seg
     fi
@@ -169,6 +172,7 @@ do_flash() {
 }
 
 do_debug() {
+    ELFFILE=$1
     test_config
     test_serial
     test_elffile
@@ -275,5 +279,7 @@ case "${ACTION}" in
     ;;
   *)
     echo "Usage: $0 {flash|debug|debug-server|reset}"
+    echo "          flash <binfile>"
+    echo "          debug <elffile>"
     ;;
 esac
@@ -18,23 +18,25 @@
 #
 #               options:
-#               BINFILE: path to the binary file that is flashed
+#               <binfile>:      path to the binary file that is flashed
+#
+# debug:        debug <elffile>
 #